@@ -3,32 +3,27 @@ package Net::IPAddress::Minimal;
 use strict;
 use warnings;
 
+use Data::Validate     'is_integer';
+use Data::Validate::IP 'is_ipv4';
 use base 'Exporter';
 
 our @EXPORT_OK = qw( ip_to_num num_to_ip invert_ip );
-
-our $VERSION = '0.02';
+our $VERSION   = '0.03';
 
 sub test_string_structure {
     my $string = shift || q{};
 
-    if ( $string =~ /(\d+\.\d+\.\d+\.\d+)/ ) {
-        # If this is an IP, return the ip flag and seperated IP classes
-        return 'ip', $1;
-    } elsif ( $string =~ /^(\d+)$/ ) {
-        return 'num';
-    } elsif ( ! $string ) {
-        return 'empty';
-    } else {
-        # If this is not an IP or a number, flag that it's an illegal string
-        return 'err';
-    }
+    is_ipv4($string)    && return 'ip';
+    is_integer($string) && return 'num';
+    $string             || return 'empty';
+
+    return 'err';
 }
 
 sub ip_to_num {
-# Converting between IP to number is according to this formula:
-# IP = A.B.C.D
-# IP Number = A x (256**3) + B x (256**2) + C x 256 + D
+    # Converting between IP to number is according to this formula:
+    # IP = A.B.C.D
+    # IP Number = A x (256**3) + B x (256**2) + C x 256 + D
     my $ip = shift;
 
     my ( $Aclass, $Bclass, $Cclass, $Dclass ) = split /\./, $ip;
@@ -45,7 +40,7 @@ sub ip_to_num {
 
 sub num_to_ip {
     my $ipnum = shift;
-   
+
     my $z = $ipnum % 256;
     $ipnum >>= 8;
     my $y = $ipnum % 256;
@@ -61,14 +56,10 @@ sub num_to_ip {
 
 sub invert_ip {
     my $input_str = shift;
-   
-    my ( $result, $ip_classes ) = test_string_structure( $input_str );
-    # $ip_classes will get a value only if an IPv4 string was submitted
-    # It is an arrayref containing 4 elements, each with the A-D class number
-
+    my $result    = test_string_structure($input_str);
     my %responses = (
-        ip    => sub { ip_to_num( $ip_classes ) },
-        num   => sub { num_to_ip( $input_str  ) },
+        ip    => sub { ip_to_num($input_str) },
+        num   => sub { num_to_ip($input_str) },
         err   => sub { 'Illegal string. Please use IPv4 strings or numbers.' },
         empty => sub { 'Empty string. Please use IPv4 strings or numbers.'   },
     );
@@ -78,7 +69,7 @@ sub invert_ip {
         return $responses{$result}->();
     }
 
-    # If non of the above was executed
+    # If none of the above was executed
     die 'Could not convert IP string / number due to unknown error';
 }
 
@@ -92,7 +83,7 @@ Net::IPAddress::Minimal - IP string to number and back
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =head1 SYNOPSIS
 
@@ -166,7 +157,7 @@ it's an IPv4 string, and IP number or something else (which is an error).
 
 Tamir Lousky, C<< <tlousky at cpan.org>  >>
 
-XSawyerX,     C<< <xsawyerx at cpan.org> >>
+SawyerX, C<< <xsawyerx at cpan.org> >>
 
 =head1 BUGS
 
